@@ -21,7 +21,11 @@ using namespace QtJson;
 YouTube::YouTube(QObject *parent) :
     ServicePlugin(parent)
 {
-    m_formatList << 137 << 22 << 135 << 134 << 18 << 133 << 160;
+    m_formatList << 37 << 22 << 35 << 34 << 18 << 36 << 17;
+
+    if (!decryptionEngine) {
+	decryptionEngine = new QScriptEngine;
+    }
 }
 
 QRegExp YouTube::urlPattern() const {
@@ -187,11 +191,9 @@ void YouTube::checkYouTubeVideoInfoPage() {
 #endif
         }
         else {
-            QString formats = response.section("adaptive_fmts=", 0, 0) + ",";
+            QString formats = response.section("&", 0, 0);
             formats.replace(QRegExp("%2C(\\w+%3D1%26|)" + separator), "," + separator);
-            QString adaptiveFormats = response.section("adaptive_fmts=", 1, 1);
-            adaptiveFormats.replace("%2C", ",");
-            this->parseYouTubeVideoPage(QScriptValue(), formats + adaptiveFormats);
+            this->parseYouTubeVideoPage(QScriptValue(), formats);
         }
     }
 
